@@ -10,11 +10,12 @@ import (
 	"time"
 
 	"github.com/pkg/errors"
-	"github.com/smallstep/cli/crypto/randutil"
 	"github.com/smallstep/cli/flags"
-	"github.com/smallstep/cli/jose"
 	"github.com/urfave/cli"
 	"go.step.sm/cli-utils/errs"
+	"go.step.sm/crypto/jose"
+	"go.step.sm/crypto/pemutil"
+	"go.step.sm/crypto/randutil"
 )
 
 func signCommand() cli.Command {
@@ -308,13 +309,13 @@ func signAction(ctx *cli.Context) error {
 	var jwk *jose.JSONWebKey
 	switch {
 	case isX5T:
-		jwk, err = jose.ParseKey(x5tKeyFile, options...)
+		jwk, err = jose.ReadKey(x5tKeyFile, options...)
 	case isX5C:
-		jwk, err = jose.ParseKey(x5cKeyFile, options...)
+		jwk, err = jose.ReadKey(x5cKeyFile, options...)
 	case key != "":
-		jwk, err = jose.ParseKey(key, options...)
+		jwk, err = jose.ReadKey(key, options...)
 	case jwks != "":
-		jwk, err = jose.ParseKeySet(jwks, options...)
+		jwk, err = jose.ReadKeySet(jwks, options...)
 	default:
 		return errs.RequiredOrFlag(ctx, "key", "jwks")
 	}
@@ -412,7 +413,11 @@ func signAction(ctx *cli.Context) error {
 	}
 
 	if isX5C {
-		certStrs, err := jose.ValidateX5C(x5cCertFile, jwk.Key)
+		certs, err := pemutil.ReadCertificateBundle(x5cCertFile)
+		if err != nil {
+			return err
+		}
+		certStrs, err := jose.ValidateX5C(certs, jwk.Key)
 		if err != nil {
 			return errors.Wrap(err, "error validating x5c certificate chain and key for use in x5c header")
 		}
@@ -424,7 +429,11 @@ func signAction(ctx *cli.Context) error {
 	}
 
 	if isX5T {
-		fingerprint, err := jose.ValidateX5T(x5tCertFile, jwk.Key)
+		certs, err := pemutil.ReadCertificateBundle(x5tCertFile)
+		if err != nil {
+			return err
+		}
+		fingerprint, err := jose.ValidateX5T(certs, jwk.Key)
 		if err != nil {
 			return errors.Wrap(err, "error validating x5t certificate and key for use in x5t header")
 		}
