@@ -2,15 +2,15 @@ package crypto
 
 import (
 	"github.com/pkg/errors"
-	"github.com/smallstep/cli/crypto/keys"
-	"github.com/smallstep/cli/crypto/pemutil"
 	"github.com/smallstep/cli/flags"
-	"github.com/smallstep/cli/jose"
 	"github.com/smallstep/cli/utils"
 	"github.com/urfave/cli"
 	"go.step.sm/cli-utils/command"
 	"go.step.sm/cli-utils/errs"
 	"go.step.sm/cli-utils/ui"
+	"go.step.sm/crypto/jose"
+	"go.step.sm/crypto/keyutil"
+	"go.step.sm/crypto/pemutil"
 )
 
 func createKeyPairCommand() cli.Command {
@@ -135,7 +135,7 @@ func createAction(ctx *cli.Context) (err error) {
 		}
 
 		var jwk *jose.JSONWebKey
-		jwk, err = jose.ParseKey(fromJWK)
+		jwk, err = jose.ReadKey(fromJWK)
 		if err != nil {
 			return err
 		}
@@ -157,7 +157,7 @@ func createAction(ctx *cli.Context) (err error) {
 			return err
 		}
 
-		pub, priv, err = keys.GenerateKeyPair(kty, crv, size)
+		pub, priv, err = keyutil.GenerateKeyPair(kty, crv, size)
 		if err != nil {
 			return err
 		}
@@ -182,7 +182,7 @@ func createAction(ctx *cli.Context) (err error) {
 		}
 	} else {
 		var pass []byte
-		pass, err = ui.PromptPassword("Please enter the password to encrypt the private key", ui.WithValue(password))
+		pass, err = ui.PromptPassword("Please enter the password to encrypt the private key", ui.WithValue(password), ui.WithValidateNotEmpty())
 		if err != nil {
 			return errors.Wrap(err, "error reading password")
 		}
